Learn R Programming

BSagri (version 0.1-6)

BOOTSimpson: Simultaneous confidence intervals for Simpson indices

Description

NOTE: This is a Test-version and is not sufficiently checked for correctness so far. Simultaneous confidence intervals for differences and ratios of Simpsons indices of diversity are calculated from data sets with repeated samples of communities and designs with more than two treatments groups. The intervals are calculated based on a stratified, non-parametric ordinary bootstrap sample of Simpsonindices, and applying the Algorithm of Besag et al.(1995) on the joint empirical distribution of differences (BOOTSimpsonD) or ratios (BOOTSimpsonR) of the original distribution.

Usage

BOOTSimpsonD(X, f, type = "Dunnett", cmat = NULL, conf.level = 0.95,
 alternative=c("two.sided", "less", "greater"), madj=TRUE, ...)

BOOTSimpsonR(X, f, type = "Dunnett", cmat = NULL, conf.level = 0.95,
 alternative=c("two.sided", "less", "greater"), madj=TRUE, ...)

Arguments

X
a data.frame of dimension n times p, containing integer entries as species counts of p species from n independent samplings
f
a factor, usually with more than two levels. Must be of length n, when X is an n times p matrix
type
a single character string, defining a contrast type. Supported options are 'Dunnett','Tukey','Sequen'; for more options, see ?contrMatratio in mratios when using BOOTSimpsonR or contrMat in multcomp<
cmat
user defined contrasts: when using BOOTSimpsonD, this should be a numeric contrast matrix, with k columns when the factor f has k levels and should define differences of these levels; when using BOOTSimpsonR, thi
conf.level
a single numeric value between 0.5 and 1
alternative
a single character string, one of 'two.sided','less' and 'greater'
madj
a single logical value, indicating whether simultaneous (if TRUE, the default) or marginal confidence intervals (if FALSE) shall be computed
...
Further arguments to be passed to the function boot from package boot; most importantly, the number of Bootstrap samples can be chosen via the parameter R (default is R=999); see ?boot for f

Value

  • If madj=TRUE, an object of class "SCSnp", see SCSnp for details. If madj=FALSE, an object of class "CInp", see CInp for details.

concept

  • simultaneous confidence
  • bootstrap
  • diversity

Details

NOTE: This is a test version!

See Also

SCSnp, these function internally make use of CCDiff.boot, CCDiff.default, CCRatio.boot, CCRatio.default, boot and estSimpsonf.

Examples

Run this code
X<-t(rmultinom(n=40,size=100,
 prob=c(0.3,0.2,0.2,0.1,0.1,0.05,0.05)))

colnames(X)<-paste("Sp",1:7,sep="")

DAT<-as.data.frame(X)

f<-as.factor(rep(c("A","B","C","D"),each=10))

SCIdunnettd<-BOOTSimpsonD(X=DAT, f=f, type = "Dunnett",
 conf.level = 0.95, alternative = "two.sided")

SCIdunnettd

SCIdunnettr<-BOOTSimpsonR(X=DAT, f=f, type = "Dunnett",
 conf.level = 0.95, alternative = "two.sided")

SCIdunnettr

Run the code above in your browser using DataLab