Learn R Programming

BSagri (version 0.1-6)

Brachycera: Eklektor counts of Brachycera

Description

In a field trial, 4 treatments were arranged in a randomized complete block design with 8 blocks and 32 plots. Soil eklektor traps were placed in each plot, on six dates from 2005-07-12 to 2005-09-25, the number of individuals of Brachycera (Flies, Order Diptera) hatching from soil were counted. The individuals were classified to the family level. Interest was in assessing potential effects of the novel treatment (Novum) on the abundance of Brachycera, compared to a near standard (Standard) and two additional standard treatments, A and B.

Usage

data(Brachycera)

Arguments

source

...

Examples

Run this code
data(Brachycera)

par(mar=c(11,5,3,1))

boxplot(Total ~ Treatment*Date, data=Brachycera, las=2, 
col=c("white","white","blue","green"))

legend(x=15, y=80, legend=levels(Brachycera$Treatment),
 fill=c("white","white","blue","green"))

Run the code above in your browser using DataLab