Learn R Programming

BSagri (version 0.1-6)

CCRatio: Ratio - contrasts of parameters simulated in BUGS

Description

Calculate ratios of parameters simulated in BUGS. This is a test version for internal use!

Usage

CCRatio(bugs, dat, cmat = NULL,
 type = c("Dunnett", "Tukey", "Sequen", "Williams", "Changepoint"))

Arguments

bugs
an object of class bugs, containing N values of the joint posterior distribution of in an N-times-P matrix named muvec
dat
an object of R2Bugsdat1w
cmat
a list containing two contrast matrices of dimensions M-times-P as elements numC, denC giving the numerator and denominator coefficients for the ratios to be calculated
type
a single character string, which type of comparisons to perform, if cmat is not given; this argument is ignored if cmat ist specified

Value

  • An object of class "CCRatio", a list with elements
  • chainsthe N-times-M matrix of the transformed joint posterior distribution
  • bugsthe bugs object, as input
  • datthe object of class "R2Bugsdat1w", as input
  • cmatthe M-times-P contrast matrix

Details

A testversion.