Learn R Programming

BSagri (version 0.1-6)

CCRatio.boot: Compute ratio contrasts of chains of joint empirical distributions.

Description

Compute contrasts of chains of joint empirical distributions. For internal use.

Usage

CCRatio.boot(x, cmat = NULL,
 type = c("Dunnett", "Tukey", "Sequen", "Williams",
 "Changepoint", "McDermott", "GrandMean", "Marcus"))

Arguments

x
an object of class "boot" as can be obtained by callinf boot in package boot with stratified bootstrap
cmat
an optional list of two contrast matrices, in entries numC and denC of the list; ncol(numC) and ncol(denC) should be the same the number of strata in x
type
a single character string, naming a contrast type available in contrMatRatio in package mratios, see ?contrMatRatio for details

concept

contrats

Details

Testversion. For internal use.