Learn R Programming

BSagri (version 0.1-6)

Cica1: Catches of Planthoppers and Leafhoppers

Description

Data of a field trial concerning the impact of a genetically modified variety on the abundance of Planthoppers and Leafhoppers. The trial was designed as a randomized complete block design with 8 blocks (Row). In each block, three treatments were randomized: a conventional variety treated with insecticides (Insecticide), a genetically modified variety (GM), and the near-isogenic line (Iso) the to genetically modified line.

Usage

data(Cica1)

Arguments

source

...

Examples

Run this code
data(Cica1)

layout(matrix(1:2,ncol=1))

ylim<-range(Cica1[,c("Au_Bonitur","Zs_sweep_netting")])

boxplot(Au_Bonitur ~ Treatment, data=Cica1,
 main= "Aucherrhyncha, visual assessment", ylim=ylim)

boxplot(Zs_sweep_netting ~ Treatment, data=Cica1,
 main="Z.scutellaris, sweep netting", ylim=ylim)

Run the code above in your browser using DataLab