Learn R Programming

BSagri (version 0.1-6)

Diptera: Soil eklektor data for some families of Diptera

Description

Hatching of some families of Diptera was recorded in summer 2005 using eklektors covering 2 square meters of soil surface each. A total of 32 eklektors were arranged in a randomized field trial. Total counts of individuals over the whole season are reported. Aim was to assess the impact of a novel treatment on the abundance of Diptera with larval development in the soil, compared to three standard treatments.

Usage

data(Diptera)

Arguments

source

...

Examples

Run this code
data(Diptera)

dev.new(width=5, height=12)

layout(matrix(1:6, nrow=6))
par(mar=c(2,5,3,1))

boxplot(Callip~Treatment, data=Diptera, horizontal=TRUE, las=1,
 main="Abundanz Callip", col=c("white","white","blue","red"))

boxplot(Chloro~Treatment, data=Diptera, horizontal=TRUE, las=1,
 main="Abundanz Chloro", col=c("white","white","blue","red"))

boxplot(Ephyd~Treatment, data=Diptera, horizontal=TRUE, las=1,
 main="Abundanz Ephyd", col=c("white","white","blue","red"))

boxplot(Droso~Treatment, data=Diptera, horizontal=TRUE, las=1,
 main="Abundanz Droso", col=c("white","white","blue","red"))

boxplot(Chiro~Treatment, data=Diptera, horizontal=TRUE, las=1,
 main="Abundanz Chiro", col=c("white","white","blue","red"))

boxplot(Ges~Treatment, data=Diptera, horizontal=TRUE, las=1,
 main="Abundanz all Diptera", col=c("white","white","blue","red"))

Run the code above in your browser using DataLab