Learn R Programming

BSagri (version 0.1-6)

ExNBCov: Simulated example data, drawn from a Negative Binomial Distribution

Description

Simulated example data, response drawn from a Negative Binomial Distribution, Covariables follow a multivariate normal distribution.

Usage

data(ExNBCov)

Arguments

Examples

Run this code
data(ExNBCov)

boxplot(Resp ~ Group, data=ExNBCov)

pairs(ExNBCov)

Run the code above in your browser using DataLab