Learn R Programming

BSagri (version 0.1-6)

Lepi: Insect counts of 12 Species

Description

Simulated data, inpired by a real field investigating the potential impact of genetically modified crop on several insect species belonging to the same order. The trial was designed as a randomized complete block design with 8 blocks (Block), and a total of 24 plots. In each block, three treatments (Treatment) were randomized: a conventional variety treated with insecticides (Ins), a genetically modified variety (GM) without insecticide treatment, and the near-isogenic variety (Iso) the to genetically modified variety, without insecticide treatment. Individuals were counted (after classification to the species level) in two different dates in each year of the trial, where the the second date was of higher importance for assessment of impacts of GM variety on non-target species. In total 12 Species were observed during the trial.

Usage

data(Lepi)

Arguments

source

Simulated data.

Examples

Run this code
data(Lepi)

str(Lepi)

summary(Lepi)

SPEC<-names(Lepi)[-(1:5)]

# Occurrence

occur<-lapply(X=Lepi[,SPEC], FUN=function(x){length(which(x>0))})

unlist(occur)

# Species with reasonable occurence in the whole data:

SPEC2<-SPEC[c(1,2,3,6,8,9,11)]

pairs(Lepi[,SPEC2])

# 


layout(matrix(1:2, ncol=1 ))
par(mar=c(2,8,2,1))

boxplot(Sp2 ~ Treatment*Year, data=Lepi, main="Species 2",
 las=1, horizontal=TRUE, col=c("red","white","white"))

boxplot(Sp3 ~ Treatment*Year, data=Lepi, main="Species 3",
 las=1, horizontal=TRUE, col=c("red","white","white"))


layout(matrix(1:3, ncol=1 ))
par(mar=c(2,8,2,1))

boxplot(Sp1 ~ Treatment*Year, data=Lepi, main="Species 1",
 las=1, horizontal=TRUE, col=c("red","white","white"))

boxplot(Sp8 ~ Treatment*Year, data=Lepi, main="Species 8",
 las=1, horizontal=TRUE, col=c("red","white","white"))

boxplot(Sp9 ~ Treatment*Year, data=Lepi, main="Species 9",
 las=1, horizontal=TRUE, col=c("red","white","white"))

Run the code above in your browser using DataLab