CCRatio(bugs, dat, cmat = NULL,
type = c("Dunnett", "Tukey", "Sequen", "Williams", "Changepoint"))bugs, containing N values of the joint posterior distribution of in an N-times-P matrix named muvecR2Bugsdat1wnumC, denC giving the numerator and denominator coefficients for the ratios to be calculatedcmat is not given; this argument is ignored if cmat ist specified