MMPoisRep: Simulated data for a simple mixed model with Poisson response
Description
Simulated data with a fixed factor cult (4 levels), with 8 randomized replications each,
a (fixed) factor time (6 levels), which are repeated measurements taken from the same experimental units.
The 32 experimental (plotid) units differ in their mean response follwing a gaussian distribution.
The response Y follows a Poisson distribution.