Rdocumentation
powered by
Learn R Programming
BSagri (version 0.1-6)
R2Bugsdat1w.data.frame: For internal use.
Description
Transform a data set to a dataset appropriate for certain OpenBUGS models.
Usage
R2Bugsdat1w.data.frame(data, response, treatment, Intercept = FALSE)
Arguments
data
a data.frame
response
a single character string, naming a numeric variable in
data
treatment
a single character string, naming a factor variable in
data
Intercept
a single logical value, defining, whether an Intercept shall be used for the construction of the design matrix
Value
a list, containing the elements
bugsdat
a list of variables appropriate for certain BUGS models
parameters
a vector of character strings, naming the parameters to save for a call to OpenBUGS
inits
a vector of initial values for the parameters
data
the original data set
Intercept
a single logical indicating whether an Intercept was used to parameterize the factor variable
Details
For internal use.