Rdocumentation
powered by
Learn R Programming
BSagri (version 0.1-6)
vcov.gamlss: Extract variance covariance matrix from objects of class gamlss
Description
Only for internal use. Extract the varaince covariance matrix corresponding to the mu parameters of a gamlss-fit.
Usage
## S3 method for class 'gamlss': vcov(object, \dots)
Arguments
object
An object of class "gamlss" as can be created by calling
gamlss
...
Currently not used.
Value
A matrix of dimension mxm, if m is the length of mu-parameters from a gamlss fit.
Details
Only for internal use. Needs implementation of warnings.
See Also
packages
gamlss
and
multcomp