vcov.geeglm: Extract variance covariance matrix from objects of class geeglm
Description
Only for internal use with function glht: Extract the variance covariance matrix corresponding to the mu parameters of a gamlss-fit.
Merely uses the method internally used in function summary.geeglm, package geepack.Usage
## S3 method for class 'geeglm':
vcov(object, \dots)
Arguments
object
An object of class "geeglm" as can be created by calling geeglm in package geepack. Value
- A matrix of dimension m times m, if m is the length of coefficients from a geeglm fit.
Details
Only for internal use. Needs implementation of warnings.See Also
packages gamlss and multcomp